Changelog
=========


1.0.0a5 (2019-02-12)
--------------------

- Fix when html is encoded as UTF-8.
  [rodfersou]


1.0.0a4 (2019-02-11)
--------------------

- Fix when there is no body tag inside html.
  [rodfersou]


1.0.0a3 (2019-01-22)
--------------------

- Added new fields:
  * One Rich Text to add content before the page embedded.
  * One Rich Text to add content after the page embedded.
  * One parameter to disable right portlet column.
  [rodfersou]


1.0.0a2 (2019-01-14)
--------------------

- Do not show title and description of the content page itself.
  [timo]

- Add pypi classifier for development status.
  [timo]


1.0.0a1 (2018-11-01)
--------------------

- Initial release.
  [kitconcept]
